unit VaxCallSession;

interface

uses
    System.Classes,

    VaxCallSessionRoute,
    VaxDefine,
    VaxCall,
    VaxCallParking,
    VaxCallPickUp,
    VaxDetectAMD,
    VaxDialTone,
    VaxDTMF,
    VaxHold,
    VaxQueue,
    VaxRingGroup,
    VaxRoom,
    VaxStealth,
    VaxTransfer,
    VaxTeleServerSIP,
    VaxServerExCOM;

type TVaxCallSession = class

    private

      m_objVaxCall: TVaxCall;
	    m_objVaxTransfer: TVaxTransfer;

	    m_objVaxQueue: TVaxQueue;
	    m_objVaxRingGroup: TVaxRingGroup;

	    m_objVaxHold: TVaxHold;
	    m_objVaxDTMF: TVaxDTMF;

      m_objVaxDialTone: TVaxDialTone;
      m_objVaxDetectedAMD: TVaxDetectAMD;

      m_objStealthListen: TVaxStealth;
      m_objCallParking: TVaxCallParking;
      m_objCallPickUp: TVaxCallPickUp;

      m_objVaxRoom: TVaxRoom;

      m_bIsCallSessionAddedToRoom: Boolean;

    public
        m_objVaxServerSIP: TVaxTeleServerSIP;

    public

        procedure OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        procedure OnCallSessionConnected(nSessionId: Integer);
        procedure OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);

        procedure OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        procedure OnCallSessionLost(nSessionId: Integer; nChannelId: Integer);

        procedure OnCallSessionHangup(nSessionId: Integer;nChannelId: Integer);
        procedure OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer);
        procedure OnCallSessionCancelled(nSessionId: Integer);

        procedure OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer);
        procedure OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer);

        procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);

        procedure OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        procedure OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer);

        procedure OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
        procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; sRoomName: String; sQueueName: String; sRingGroupName: String; nFromPeerType: Integer; sFromPeerName: String; nToPeerType: Integer; sToPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);

        procedure OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);

        procedure OnAddCallSessionToQueueSuccess( sQueueName: String; nSessionId: Integer);
        procedure OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer);

        procedure OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer);
        procedure OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer);

    public

        constructor Create();

        function AcceptCallSession(nSessionId: Integer; sCallerName, sCallerId, sDialNo: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        procedure CloseCallSession(nSessionId: Integer);

end;

implementation

        constructor TVaxCallSession.Create();
        begin
            inherited;

            m_bIsCallSessionAddedToRoom := False;

            m_objVaxCall := TVaxCall.Create();
            m_objVaxTransfer := TVaxTransfer.Create();

            m_objVaxQueue := TVaxQueue.Create();
            m_objVaxRingGroup := TVaxRingGroup.Create();

            m_objVaxHold := TVaxHold.Create();
            m_objVaxDTMF := TVaxDTMF.Create();

            m_objVaxDialTone := TVaxDialTone.Create();
            m_objVaxDetectedAMD := TVaxDetectAMD.Create();

            m_objStealthListen := TVaxStealth.Create();
            m_objCallParking := TVaxCallParking.Create();
            m_objCallPickUp := TVaxCallPickUp.Create();

            m_objVaxRoom := TVaxRoom.Create();

        end;

        function TVaxCallSession.AcceptCallSession(nSessionId: Integer; sCallerName, sCallerId, sDialNo: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        var
            bResult: Boolean;
        begin

            bResult := TVaxServerExCOM.mVaxExCOM.AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName);

            if(bResult = False) then
            begin
                TVaxServerExCOM.mVaxExCOM.RejectCallSession(nSessionId, 404, 'Not Found');
                Exit(False);
            end;

            Result := True;
        end;

        procedure TVaxCallSession.CloseCallSession(nSessionId: Integer);
        begin
            TVaxServerExCOM.mVaxExCOM.CloseCallSession(nSessionId);
        end;

        procedure TVaxCallSession.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; sRoomName: String; sQueueName: String; sRingGroupName: String; nFromPeerType: Integer; sFromPeerName: String; nToPeerType: Integer; sToPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);
        var
          bProcessed: Boolean;
        begin

          bProcessed := m_objVaxRoom.OnIncomingCall(nSessionId, sRoomName);
          m_bIsCallSessionAddedToRoom := bProcessed;
          if(bProcessed) Then Exit();

          bProcessed := m_objVaxQueue.OnIncomingCall(nSessionId, sCallerName, sCallerId, sQueueName);
          if(bProcessed) Then Exit();

          bProcessed := m_objVaxRingGroup.OnIncomingCall(nSessionId, sCallerName, sCallerId, sRingGroupName);
          if(bProcessed) Then Exit();

          bProcessed := m_objCallParking.OnIncomingCall(nSessionId, sDialNo, nFromPeerType);
          if(bProcessed) Then Exit();

          bProcessed := m_objCallPickUp.OnIncomingCall(nSessionId, sDialNo, nFromPeerType, sFromPeerName);
          if(bProcessed) Then Exit();

          bProcessed := m_objStealthListen.OnIncomingCall(nSessionId, sDialNo, nFromPeerType, sFromPeerName);
          if(bProcessed) Then Exit();

          m_objVaxCall.OnIncomingCall(nSessionId, sCallerName, sCallerId, sDialNo, nFromPeerType, sFromPeerName, nToPeerType, sToPeerName);

        end;

        procedure TVaxCallSession.OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
           m_objVaxCall.OnCallSessionFailed(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxCallSession.OnCallSessionConnected(nSessionId: Integer);
        begin

            if(m_bIsCallSessionAddedToRoom = True) then
            begin
              m_objVaxRoom.OnCallSessionConnected(nSessionId);
              Exit();
            end;

            m_objVaxCall.OnCallSessionConnected(nSessionId);
        end;

        procedure TVaxCallSession.OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);
        begin
             m_objVaxCall.OnCallSessionClosed(nSessionId, nChannelId, nReasonCode);
        end;

        procedure TVaxCallSession.OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer);
        begin
            m_objVaxHold.OnCallSessionOnHold(nSessionId, nChannelId);
        end;

        procedure TVaxCallSession.OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer);
        begin
           m_objVaxHold.OnCallSessionOffHold(nSessionId, nChannelId);
        end;

        procedure TVaxCallSession.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        var bProcessed: Boolean;
        begin

          bProcessed := m_objCallParking.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererChannelId, sTransferer, sTransferee, sTransferTo);
          if(bProcessed) Then Exit();

          m_objVaxTransfer.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererChannelId, sTransferer, sTransferee, sTransferTo);

        end;

        procedure TVaxCallSession.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        begin
            m_objVaxTransfer.OnCallSessionTransferConsult(nTransfererSessionId, nTransfererChannelId, nTransferToSessionId, nTransferToChannelId, sTransferer, sTransferee, sTransferTo);
        end;

        procedure TVaxCallSession.OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
            m_objVaxCall.OnCallSessionConnecting(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxCallSession.OnCallSessionLost(nSessionId: Integer; nChannelId: Integer);
        begin
          m_objVaxCall.OnCallSessionLost(nSessionId, nChannelId);
        end;

        procedure TVaxCallSession.OnCallSessionHangup(nSessionId: Integer; nChannelId: Integer);
        begin
          m_objVaxCall.OnCallSessionLost(nSessionId, nChannelId);
        end;

        procedure TVaxCallSession.OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer);
        begin
          m_objVaxCall.OnCallSessionTimeout(nSessionId, nChannelId);
        end;

        procedure TVaxCallSession.OnCallSessionCancelled(nSessionId: Integer);
        begin
          m_objVaxCall.OnCallSessionCancelled(nSessionId);
        end;

        procedure TVaxCallSession.OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
        begin
           m_objVaxDTMF.OnDetectedDigitDTMF(nSessionId, nChannelId, sDigitDTMF);
        end;

        procedure TVaxCallSession.OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
           m_objVaxTransfer.OnCallSessionTransfering(nSessionId, nTransferType, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxCallSession.OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer);
        begin
          m_objVaxTransfer.OnCallSessionTransfered(nSessionId, nTransferType);
        end;

        procedure TVaxCallSession.OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);
        begin
        end;

        procedure TVaxCallSession.OnAddCallSessionToQueueSuccess(sQueueName: String; nSessionId: Integer);
        begin
             m_objVaxQueue.OnAddCallSessionToQueueSuccess(sQueueName, nSessionId);
        end;

        procedure TVaxCallSession.OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer);
        begin
            m_objVaxQueue.OnAddCallSessionToQueueFailed(sQueueName, nSessionId);
        end;

        procedure TVaxCallSession.OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer);
        begin
            m_objVaxRingGroup.OnAddCallSessionToRingGroupSuccess(sGroupName, nSessionId);
        end;

        procedure TVaxCallSession.OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer);
        begin
            m_objVaxRingGroup.OnAddCallSessionToRingGroupFailed(sGroupName, nSessionId);
        end;

end.

