﻿Public Class RoomForm

    Private m_objVaxTeleSIP As cVaxServerSIP

    Public Sub New(ByRef objVaxTeleSIP As cVaxServerSIP)

        InitializeComponent()
        m_objVaxTeleSIP = objVaxTeleSIP

    End Sub

    Private Sub btnAddRoom_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAddRoom.Click

        If AddRoomChecks() = False Then
            Return
        End If

        If (ComboRoomName.FindStringExact(ComboRoomName.Text) <> -1) Then
            If (MessageBox.Show("Room already exists, do you want to continue?", "VaxTeleSIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) = DialogResult.No) Then
                Return
            End If
        End If

        If (ComboRoomName.Items.Contains(ComboRoomName.Text)) Then
            m_objVaxTeleSIP.RemoveRoom(ComboRoomName.Text.Trim())
        End If

        If (m_objVaxTeleSIP.AddRoom(ComboRoomName.Text.Trim(), EditRoomNo.Text.Trim()) = False) Then
            MessageBox.Show("Room could not be added/updated or Please start the server first. or Can't assign same Room-No to two different rooms.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Error)
            Return
        End If

        If (Not ComboRoomName.Items.Contains(ComboRoomName.Text)) Then
            ComboRoomName.Items.Add(ComboRoomName.Text)
        End If

        MessageBox.Show("Room added/updated successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Sub btnRemoveRoom_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRemoveRoom.Click

        If ComboRoomName.Text.Length = 0 Then
            MessageBox.Show("Please enter room name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Exit Sub
        End If

        Dim nIndex As Integer = ComboRoomName.FindStringExact(ComboRoomName.Text)
        If (nIndex = -1) Then Return

        m_objVaxTeleSIP.RemoveRoom(ComboRoomName.Text)
        ComboRoomName.Items.RemoveAt(nIndex)

        ClearDlgContent()

        If (ComboRoomName.Items.Count > 0) Then
            ComboRoomName.SelectedIndex = 0
        End If

        ShowRoomDetails()

        MessageBox.Show("Room removed successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Sub ClearDlgContent()

        EditRoomNo.Text = ""
        ComboRoomName.Text = ""

    End Sub

    Private Sub ComboRoomName_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ComboRoomName.SelectedIndexChanged
        ShowRoomDetails()
    End Sub

    Private Function AddRoomChecks() As Boolean

        If (ComboRoomName.Text.Length = 0) Then
            MessageBox.Show("Room Name can't be empty.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Information)
            Return False
        End If

        If (EditRoomNo.Text.Length = 0) Then
            MessageBox.Show("Room No can't be empty", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Information)
            Return False
        End If

        Dim nCount As Integer
        Dim sDigit As String = "0123456789"

        For nCount = 0 To EditRoomNo.Text.Length - 1
            If sDigit.IndexOf(EditRoomNo.Text.Chars(nCount)) = -1 Then
                MessageBox.Show("Room No should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
                Return False
            End If
        Next

        Return True

    End Function

    Private Sub AddRooms()

        ComboRoomName.Items.Clear()

        Dim objRoomList As ArrayList = New ArrayList()
        m_objVaxTeleSIP.GetRoomAll(objRoomList)

        If (objRoomList.Count <= 0) Then Return

        Dim nIndex = 0
        For nIndex = 0 To objRoomList.Count - 1
            ComboRoomName.Items.Add(objRoomList.Item(nIndex))
        Next

        If (ComboRoomName.Items.Count > 0) Then
            ComboRoomName.SelectedIndex = 0
        End If

    End Sub

    Private Sub ShowRoomDetails()

        Dim sRoomName As String = ComboRoomName.Text
        If (sRoomName.Length = 0) Then Return

        Dim sRoomNo As String = ""

        If m_objVaxTeleSIP.GetRoomDetails(sRoomName, sRoomNo) = False Then
            Return
        End If

        EditRoomNo.Text = sRoomNo

    End Sub

    Public Sub OnSetActive()

        AddRooms()
        ShowRoomDetails()

    End Sub

End Class