unit VaxRoomList;

interface

uses
    System.SysUtils,
    System.Classes,
    Generics.Collections;

type TVaxRoomDetails = class

public

    m_sRoomName, m_sRoomNo : string;

end;

type TVaxRoomList = class

    private

        m_objMapConfRoomByName : TObjectDictionary<string, TVaxRoomDetails>;
        m_objMapConfRoomByNo : TObjectDictionary<string, TVaxRoomDetails>;

    private

    function GenKey(sValue : string) : string;
    procedure DeleteRoomAll();

    function FindRoomByName(sRoomName : string) : TVaxRoomDetails;
    function FindRoomByNo(sRoomNo : string) : TVaxRoomDetails;

    public

    constructor Create();
    Destructor Destroy();

    procedure ResetOBJ();

    function AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
    procedure RemoveRoom(sRoomName : string);

    function GetRoomName(sRoomNo : string) : string;

    function GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;

    function IsRoomNoExist(sRoomNo : string) : Boolean;

    function GetRoomAll(var pRoomList : TStringList) : Boolean;

end;

implementation

    constructor TVaxRoomList.Create();
    begin
        m_objMapConfRoomByName := TObjectDictionary<string, TVaxRoomDetails>.Create(256);
        m_objMapConfRoomByNo := TObjectDictionary<string, TVaxRoomDetails>.Create(256);
    end;

    Destructor TVaxRoomList.Destroy();
    begin
        DeleteRoomAll();
        m_objMapConfRoomByName.Free;
    end;

    function TVaxRoomList.GenKey(sValue : string) : string;
    begin
        Result := AnsiLowerCase(sValue);
    end;

    procedure TVaxRoomList.DeleteRoomAll();
    begin
        m_objMapConfRoomByName.Clear;
    end;

    function TVaxRoomList.FindRoomByName(sRoomName : string) : TVaxRoomDetails;
    var objConfRoom : TVaxRoomDetails;
        bResult : Boolean;
    begin
        objConfRoom := nil;

        bResult := m_objMapConfRoomByName.TryGetValue(AnsiLowerCase(sRoomName), objConfRoom);
        if(bResult = False) then Exit(Nil);

        Result := objConfRoom;
    end;

    function TVaxRoomList.FindRoomByNo(sRoomNo : string) : TVaxRoomDetails;
    var objConfRoom : TVaxRoomDetails;
    begin
        objConfRoom := nil;

        If NOT m_objMapConfRoomByNo.ContainsKey(sRoomNo) then
            Exit(nil);

        Result := m_objMapConfRoomByNo.Items[AnsiLowerCase(sRoomNo)];
    end;

    procedure TVaxRoomList.ResetOBJ();
    begin
        DeleteRoomAll();
    end;

    function TVaxRoomList.AddRoom(sRoomName : string ; sRoomNo : string) : Boolean;
    var
        sKey : string;
        objRoom : TVaxRoomDetails;
    begin

        objRoom := FindRoomByName(sRoomName);
        if(objRoom <> nil) then
        begin
          Result := False;
          Exit;
        end;

        objRoom := FindRoomByNo(sRoomNo);
        if(objRoom <> nil) then
        begin
          Result := False;
          Exit;
        end;

        objRoom := TVaxRoomDetails.Create();

        objRoom.m_sRoomName := sRoomName;
        objRoom.m_sRoomNo := sRoomNo;

        sKey := GenKey(sRoomName);
        m_objMapConfRoomByName.Add(sKey, objRoom);

        sKey := GenKey(sRoomNo);
        m_objMapConfRoomByNo.Add(sKey, objRoom);

        Result := True;

    end;

    procedure TVaxRoomList.RemoveRoom(sRoomName : string);
    var
        sKey : string;
        objRoom : TVaxRoomDetails;
        sRoomNo : string;
        nCount : Integer;
    begin

        objRoom := FindRoomByName(sRoomName);
        if(objRoom = nil) then Exit;

         sKey := GenKey(objRoom.m_sRoomName);
         sRoomNo := objRoom.m_sRoomNo;

         //Remove by 'RoomNo'
         m_objMapConfRoomByNo.Remove(sRoomNo);

         // Remove by 'RoomName'
         m_objMapConfRoomByName.Remove(sKey);

         nCount := m_objMapConfRoomByNo.Count;

    end;

    function TVaxRoomList.GetRoomName(sRoomNo : string) : string;
    var
        objRoom : TVaxRoomDetails;
    begin

        objRoom := FindRoomByNo(sRoomNo);
        if(objRoom  = nil) then
        begin
            Result := '';
            Exit;
        end;

        Result := objRoom.m_sRoomName;
    end;

    function TVaxRoomList.GetRoomDetails(sRoomName : string; var sRoomNo : string) : Boolean;
    var
        objRoom : TVaxRoomDetails;
    begin

        objRoom := FindRoomByName(sRoomName);
        if(objRoom  = nil) then
        begin
            Result := False;
            Exit;
        end;

        sRoomNo := objRoom.m_sRoomNo;
        Result := True;

    end;

    function TVaxRoomList.IsRoomNoExist(sRoomNo : string) : Boolean;
    var
        objRoom : TVaxRoomDetails;
    begin

        objRoom := FindRoomByNo(sRoomNo);
        if(objRoom  = nil) then
        begin
            Exit(False);
        end;

        Result := True;
    end;

    function TVaxRoomList.GetRoomAll(var pRoomList : TStringList) : Boolean;
    var
        objRoom : TVaxRoomDetails;
    begin

        for objRoom in m_objMapConfRoomByName.Values do
        begin
          pRoomList.Add(objRoom.m_sRoomName );
        end;

        Result := True;

    end;


end.
